@@ -1,6 +1,6 @@
 /* Fake libiberty.h for Bison.
 
-   Copyright (C) 2002-2004, 2009-2011 Free Software Foundation, Inc.
+   Copyright (C) 2002-2004, 2009-2013 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 # define BISON_LIBIBERTY_H_ 1
 
 # ifndef __attribute__
-#  if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 8) || __STRICT_ANSI__
+#  if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 8)
 #   define __attribute__(x)
 #  endif
 # endif
